# -*- coding: utf-8 -*-
import math
import matplotlib.pyplot as plt
import meca_energie


## Extraction des donnees du fichier csv
# Appel à la fonction extraire_donnees, definie dans le fichier meca_energie
t, x, z = meca_energie.extraire_donnees('mouvement_plan_incline.csv')


## Definition des constantes
# Masse du camion en kg
m = 0.200
# Intensité de la pesanteur en N/kg
g = 9.81
# Pas temporel entre 2 positions
delta_t = t[1] - t[0]

# Appel de la fonction permettant de calculer une dérivee
# (fonction definie dans le fichier meca_energie)
# Calcul de la derivee de x et de z pour obtenir les vitesses selon les axes x/z
vx = meca_energie.derive(x, delta_t)
vz = meca_energie.derive(z, delta_t)

# Definition des listes amenees a contenir les valeurs des différentes energies
Epp = []
Ec = []
Em = []

# Calcul des energies pour chaque position du mobile
for i in range(len(t)):
    Epp.append(m*g*z[i])
    # Calcul de la vitesse v a partir des composantes du vecteur vitesse
    # math.sqrt(...) renvoie la racine carree
    v = math.sqrt(vx[i]**2 + vz[i]**2)
    Ec.append(0.5*m*v**2)
    Em.append(Epp[i]+Ec[i])


### Représentation graphique

# Definition des courbes
plt.plot(t, Epp, color='b', marker='+', label = "Epp")
plt.plot(t, Ec, color='r', marker='x', label = "Ec")
plt.plot(t, Em, color='g', marker='o', label = "Em")

# Réglages axes et grille
plt.axis([0, max(t), 0, 1.05*max(max(Ec), max(Epp), max(Em))])
plt.grid(True)

# Labels du graphique
plt.xlabel('Temps (s)')
plt.ylabel('Énergie (J)')
plt.title('Évolution des énergies au cours du temps')

# Affichage de la légende et du graphique
plt.legend(loc='center left')
plt.show()