# -*- coding: utf-8 -*-

# Fonction d'extraction des donnees du fichier
def extraire_donnees(chemin_du_fichier):
    
    # Ouverture du fichier contenant les donnees de l'acquisition
    with open(chemin_du_fichier, 'r') as fichier_donnees:
        # Lecture de chaque ligne du fichier et affectation de chacune d'entre
        # elles dans la liste "lignes"
        lignes = fichier_donnees.readlines()
    
    # Chaque ligne contient 3 donnees : temps, abscisse et altitude de chaque point
    # Creation de listes vierges pour chacune des grandeurs
    liste_t = []
    liste_x = []
    liste_z = []
    
    # Extraction des 3 donnees pour chaque ligne du fichier
    # puis ajout dans la liste correspondante
    for i in range(len(lignes)):
        # Remplacement des ',' par des '.'
        lignes[i] = lignes[i].replace(',', '.')
        # Suppression de la 3e tabulation et du saut de fin de ligne
        lignes[i] = lignes[i].rstrip('\t\n')

    # On remplit les listes avec les valeurs
    for ligne in lignes[0:]:
        # try...except permet de lever les exceptions generees par le programme
        try:
            # Decoupage de la ligne apres chaque caractère tabulation '\t'
            t, x, z = ligne.split('\t')
            liste_t.append(float(t))
            liste_x.append(float(x))
            liste_z.append(float(z))
        except:
            pass
    return liste_t, liste_x, liste_z
    

# Fonction permettant le calcul de la derivee temporelle d'une grandeur
# Prend en entree une liste de valeurs de la grandeur consideree
# et l'intervalle temporel dt entre 2 points
def derive(liste, dt):
    # Liste des points de la derivee (vierge au départ)
    derivee = []
    nb_points = len(liste)
    if nb_points > 1:  # S'il y a au moins deux points
        # On calcule la derivee à partir du 1er et du 2e point
        derivee.append((liste[1]-liste[0])/dt)
        # Pour les autres points, on calcule la derivee a partir des points
        # suivant et precedent
        for i in range(1, nb_points-1) :
            derivee.append((liste[i+1]-liste[i-1])/(2*dt))
        # Pour le dernier point, on calcule sa derivee a partir du point
        # precedent
        derivee.append((liste[-1]-liste[-2])/dt)
    return derivee